/*
        Copyright (C) 2004 Jonas Lindholm

        This software was developed by Jonas Lindholm, jlhm@usa.net

        History

        V1.0            Jonas Lindholm  2004-05-14

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <pthread.h>

#include <starlet.h>
#include <descrip.h>
#include <ssdef.h>
#include <stsdef.h>

#include <ldap.h>

#include "lgildap.h"
#include "server.h"


pthread_mutex_t		putmsgmtx;

FILE			*out;

/*
	Description:

	This routine is invoked to print the message to SYS$OUTPUT.
	We prefix all messages with a timestamp.

	To prevent that two or more threads try to write output at
	the same time we use a mutex to serialize the write. 

	INPUT:		descriptor to message text
			private data

	OUTPUT:		0. this will prevent sys$putmsg to write the message it self.
*/

int putmsg(struct dsc$descriptor_s *msgdsc, int p) {
	time_t		t = time(NULL);

	fprintf(out, "%24.24s: %*.*s\n", ctime(&t), msgdsc->dsc$w_length, msgdsc->dsc$w_length, msgdsc->dsc$a_pointer);

	return 0;
}


/*
	Description:

	This routine is invoked as the secondary last chance exception handler.
	As C RTL does not support the lib$establish in native alpha code we use
	this method instead to handle our private messages.

	We also specify a private routine that print the message.

	Because we don't expect too many messages to be written the open and close
	of the output file should not create any load on the system.

	INPUT:		standard VMS signal and mechanism arrays.

	OUTPUT:		none 

	IMPLICIT:	do not generate any exception with the LLSRV messages from
			any AST routine.
*/

int exchndl(int unsigned sigargs[], int unsigned mchargs[]) {

	if (((union stsdef *)&sigargs[1])->sts$v_fac_no == (1378 + 2048)) {

		sigargs[0] -= 2;

		pthread_mutex_lock(&putmsgmtx);

		out = fopen("SYS$OUTPUT", "a");

		sys$putmsg(sigargs, &putmsg, 0, 0);

		fclose(out); /* this will flush the file and make it readable */

		pthread_mutex_unlock(&putmsgmtx);

		return SS$_CONTINUE;

	} 

	return SS$_RESIGNAL;
}


/*
	Description:

	This routine initaite the mutex used to protect the output to the log file as
	we don't want several threads using the sys$putmsg at the same time.

	INPUT:		none

	OUTPUT:		none
*/

int exception_init() {
	int		stat;

	pthread_mutex_init(&putmsgmtx, NULL);
 
	out = fopen("SYS$OUTPUT", "w"); /* create new output file */
	fclose(out);

	stat = sys$setexv(1, &exchndl, 0, 0);

	return stat;
}
